==> nextcloud-app-tasks-0.14.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/mk.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Важно",
    "Today" : "Денес",
    "Week" : "Седмица",
    "All" : "Сите",
    "Current" : "Моменталлни",
    "Completed" : "Завршено",
    "Tasks" : "Задачи",
    "The Tasks app for Nextcloud" : "Апликација за задачи за Nextcloud",
    "Default list" : "Стандардна листа",
    "Visibility of Smart Collections" : "Видливост на паметни колекции",
    "Hidden" : "Сокриен",
    "Visible" : "Видлив",
    "Automatic" : "Автоматски",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "Unshare with {displayName}" : "Не споделувај со {displayName}",
    "Unable to delete the share." : "Неможе да се избрише споделениот контакт",
    "Unable to change permissions." : "Неможе да се променат дозволите.",
    "Edit" : "Уреди",
    "Copy private link" : "Копирај приватен линк",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Delete" : "Избриши",
    "Unshare" : "Отстрани споделување",
    "Cancel" : "Откажи",
    "Save" : "Сними",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Ова ќе го избрише календарот \"{calendar}\" и сите настани и задачи во него.",
    "This will unshare the calendar \"{calendar}\"." : "Ова ќе направи да не се споделува повеќе календарот \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Ова ќе ја избрише листата  \"{list}\" и сите задачи во неа.",
    "This will unshare the list \"{list}\"." : "Ова ќе направи да не се споделува повеќе листата \"{list}\".",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "List link copied to clipboard." : "Линкот до листата е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "List link could not be copied to clipboard." : "Линк до листата неможе да се копира во клипборд.",
    "The name \"{calendar}\" is already used." : "Името \"{calendar}\" е веќе искористено.",
    "An empty name is not allowed." : "Празно име не е дозволено.",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "An error occurred, unable to delete the list." : "Настана грешка, неможе да се избрише листата.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришење на календарот за {countdown} секунда","Бришење на календарот за {countdown} секунди"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Отстранување на споделување на календар за {countdown} секунда","Отстранување на споделување на календар за {countdown} секунди"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Бришење на листата за {countdown} секунда","Бришење на листата за {countdown} секунди"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Отстранување на споделување на листа за {countdown} секунда","Отстранување на споделување на листа за {countdown} секунди"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Споделено со 1 лице","Споделено со {num} лица"],
    "Add this as a new tag" : "Додади ја како нова ознака",
    "Delete all completed tasks." : "Избриши ги сите завршени задачи.",
    "Delete completed tasks." : "Избриши завршени задачи.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Избриши ги сите завршени задали од календарот \"{calendar}\".",
    "No errors" : "Нема грешки",
    "Open your browser console for more details" : "Отворете ја конзолата на прелистувачот за повеќе детали",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Ова ќе избрише {taskCount} завршена задачи и подзадачи од календарот \"{calendar}\".","Ова ќе избрише {taskCount} завршени задачи и подзадачи од календарот \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Неможе да се избрише {failedCount} задача.","Неможе да се избришат {failedCount} задачи."],
    "Add an important task to \"{calendar}\"…" : "Додади важна задача во \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Додади краен рон на задачите во \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Додади моментална задача во \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Додади задача во \"{calendar}\"…",
    "Load all completed tasks." : "Вчитај ги сите завршени задачи.",
    "Change sort order" : "Променете го редоследот",
    "Relevance" : "Релевантност",
    "Sort by completed state, due date, priority, start date and summary." : "Подреди по завршена состојба, краен рок, приоритет, датум на започнување и резиме.",
    "Start date" : "Датум на започнување",
    "Sort by start date and summary." : "Подреди по датум на започнување и резиме.",
    "Due date" : "До датум",
    "Sort by due date and summary." : "Подреди по краен рок и резиме.",
    "Created date" : "Датум на креирање",
    "Sort by created date and summary." : "Подреди по датум на креирање и резиме.",
    "Last modified" : "Скоро изменети",
    "Sort by last-modified date and summary." : "Подреди по датум на последна промена и резиме.",
    "Completed date" : "Датум на завршување",
    "Sort by completed date." : "Подреди по датум на завршување.",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Подреди по приоритет и резиме.",
    "Alphabetically" : "Азбучно",
    "Sort by summary and priority." : "Подреди по резиме и приоритет.",
    "Manually" : "Рачно",
    "Sort by manual order." : "Подреди по рачен редослед.",
    "{complete} % completed" : "{complete} % завршено",
    "Add subtask" : "Додади подзадача",
    "Show subtasks" : "Прикажи подзадачи",
    "Hide subtasks" : "Сокриј подзадачи",
    "Delete task" : "Избриши задача",
    "[Yesterday]" : "[Вчера]",
    "[Today]" : "[Денес]",
    "[Tomorrow]" : "[Утре]",
    "[Completed yesterday]" : "[Завршени вчера]",
    "[Completed today]" : "[Завршени денес]",
    "[Completed tomorrow]" : "[Завршени утре]",
    "[Yesterday at] LT" : "[Вчера во] LT",
    "[Today at] LT" : "[Денес во] LT",
    "[Tomorrow at] LT" : "[Утре во] LT",
    "L [at] LT" : "L [во] LT",
    "[Completed yesterday at] LT" : "[Завршени вчера во] LT",
    "[Completed today at] LT" : "[Завршени денес во] LT",
    "[Completed tomorrow at] LT" : "[Завршени утре во] LT",
    "[Completed] L [at] LT" : "[Завршени] L [во] LT",
    "Add a subtask to \"{task}\"…" : "Додади подзадача во \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Бришење на задачата за {countdown} секунда","Бришење на задачата за {countdown} секунди"],
    "Task is completed" : "Задачата е завршена",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Завршена задача","%n Завршени задачи"],
    "Tomorrow" : "Утре",
    "Add List…" : "Додади листа...",
    "New List" : "Нова листа",
    "All day" : "Цели денови",
    "Select a classification" : "Избери класификација",
    "Select a status" : "Избери статус",
    "Select tags" : "Избери ознаки",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделен, прикажи зафатено",
    "When shared hide this event" : "Кога е споделен, сокриј го настанот",
    "Needs action" : "Потребна е акција",
    "In process" : "Во тек",
    "Canceled" : "Откажано",
    "Loading task from server." : "Вчитување на задачите од серверот.",
    "Task not found!" : "Задачата не е пронајдена!",
    "[Starts today]" : "[Започнува денес]",
    "[Starts tomorrow]" : "[Започнува утре]",
    "[Starts on] LL" : "[Започнува на] LL",
    "[Started yesterday]" : "[Започна вчера]",
    "[Started on] LL" : "[Започна на] LL",
    "[Started today at] LT" : "[Започна денес во] LT",
    "[Starts today at] LT" : "[Започнува денес во] LT",
    "[Starts tomorrow at] LT" : "[Започнува утре во] LT",
    "[Starts on] LL [at] LT" : "[Започнува на] LL [во] LT",
    "[Started yesterday at] LT" : "[Започна вчера во] LT",
    "[Started on] LL [at] LT" : "[Започна на] LL [во] LT",
    "Set start date" : "Постави почетен датум",
    "[Due today]" : "[До денес]",
    "[Due tomorrow]" : "[До утре]",
    "[Due on] LL" : "[До] LL",
    "[Was due yesterday]" : "[Требаше вчера]",
    "[Was due on] LL" : "[Требање до] LL",
    "[Was due today at] LT" : "[Требаше до денес во] LT",
    "[Due today at] LT" : "[До денес во] LT",
    "[Due tomorrow at] LT" : "[До утре во] LT",
    "[Due on] LL [at] LT" : "[До] LL [во] LT",
    "[Was due yesterday at] LT" : "[Требаше вчера во] LT",
    "[Was due on] LL [at] LT" : "[Требање до] LL [во] LT",
    "Set due date" : "Постави краен рок",
    "Priority {priority}: low" : "Приоритет {priority}: низок",
    "Priority {priority}: medium" : "Приоритет {priority}: среден",
    "Priority {priority}: high" : "Приоритет {priority}: висок",
    "No priority assigned" : "Нема дадено приоритет",
    "{percent} % completed" : "{percent} % завршено",
    "Successfully created the task." : "Успешно креирана задача.",
    "Could not delete the task." : "Неможе да се избрише задачата.",
    "Synchronizing to the server." : "Синхронизација со серверот.",
    "Task successfully saved to server." : "Задачата е успешно зачувана на серверот.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Неможе да се ажурира задачата бидејќи постои некој промена во задачата на серверот. Кликете на освежи, локалните промени ќе се отфрлат.",
    "Could not update the task." : "Неможе да се ажурира задачата.",
    "Successfully updated the task." : "Успешно ажурирање на задачата.",
    "Task successfully moved to new calendar." : "Задачата е успешно преместена во нов календар.",
    "An error occurred" : "Настана грешка"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/mk.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Важно",
    "Today" : "Денес",
    "Week" : "Седмица",
    "All" : "Сите",
    "Current" : "Моменталлни",
    "Completed" : "Завршено",
    "Tasks" : "Задачи",
    "The Tasks app for Nextcloud" : "Апликација за задачи за Nextcloud",
    "Default list" : "Стандардна листа",
    "Visibility of Smart Collections" : "Видливост на паметни колекции",
    "Hidden" : "Сокриен",
    "Visible" : "Видлив",
    "Automatic" : "Автоматски",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "Can edit" : "Може да се уредува",
    "Unshare with {displayName}" : "Не споделувај со {displayName}",
    "Unable to delete the share." : "Неможе да се избрише споделениот контакт",
    "Unable to change permissions." : "Неможе да се променат дозволите.",
    "Edit" : "Уреди",
    "Copy private link" : "Копирај приватен линк",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Export" : "Извези",
    "Delete" : "Избриши",
    "Unshare" : "Отстрани споделување",
    "Save" : "Сними",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Ова ќе го избрише календарот \"{calendar}\" и сите настани и задачи во него.",
    "This will unshare the calendar \"{calendar}\"." : "Ова ќе направи да не се споделува повеќе календарот \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Ова ќе ја избрише листата  \"{list}\" и сите задачи во неа.",
    "This will unshare the list \"{list}\"." : "Ова ќе направи да не се споделува повеќе листата \"{list}\".",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "List link copied to clipboard." : "Линкот до листата е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "List link could not be copied to clipboard." : "Линк до листата неможе да се копира во клипборд.",
    "The name \"{calendar}\" is already used." : "Името \"{calendar}\" е веќе искористено.",
    "An empty name is not allowed." : "Празно име не е дозволено.",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "An error occurred, unable to delete the list." : "Настана грешка, неможе да се избрише листата.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришење на календарот за {countdown} секунда","Бришење на календарот за {countdown} секунди"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Отстранување на споделување на календар за {countdown} секунда","Отстранување на споделување на календар за {countdown} секунди"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Бришење на листата за {countdown} секунда","Бришење на листата за {countdown} секунди"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Отстранување на споделување на листа за {countdown} секунда","Отстранување на споделување на листа за {countdown} секунди"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Споделено со 1 лице","Споделено со {num} лица"],
    "Trash bin" : "Корпа за отпадоци",
    "Name" : "Име",
    "Deleted" : "Избришани",
    "Restore" : "Врати",
    "Delete permanently" : "Избриши",
    "Empty trash bin" : "Испразни ја корпата со отпадоци",
    "Untitled task" : "Неименувана задача",
    "Untitled event" : "Неименуван настан",
    "Unknown calendar" : "Непознат календар",
    "Could not load deleted calendars and objects" : "Неможат да се вчитаат избришаните календари и елементи",
    "Could not restore calendar or event" : "Неможе да се врати календар или настан",
    "Do you really want to empty the trash bin?" : "Дали навистина сакате да ја испразните kорпаta за отпадоци?",
    "Select a calendar" : "Избери календар",
    "Add this as a new tag" : "Додади ја како нова ознака",
    "Delete all completed tasks." : "Избриши ги сите завршени задачи.",
    "Delete completed tasks." : "Избриши завршени задачи.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Избриши ги сите завршени задали од календарот \"{calendar}\".",
    "No errors" : "Нема грешки",
    "Open your browser console for more details" : "Отворете ја конзолата на прелистувачот за повеќе детали",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Ова ќе избрише {taskCount} завршена задачи и подзадачи од календарот \"{calendar}\".","Ова ќе избрише {taskCount} завршени задачи и подзадачи од календарот \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Неможе да се избрише {failedCount} задача.","Неможе да се избришат {failedCount} задачи."],
    "Add an important task to \"{calendar}\"…" : "Додади важна задача во \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Додади краен рон на задачите во \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Додади моментална задача во \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Додади задача во \"{calendar}\"…",
    "Load all completed tasks." : "Вчитај ги сите завршени задачи.",
    "Change sort order" : "Променете го редоследот",
    "Relevance" : "Релевантност",
    "Sort by completed state, due date, priority, start date and summary." : "Подреди по завршена состојба, краен рок, приоритет, датум на започнување и резиме.",
    "Start date" : "Датум на започнување",
    "Sort by start date and summary." : "Подреди по датум на започнување и резиме.",
    "Due date" : "До датум",
    "Sort by due date and summary." : "Подреди по краен рок и резиме.",
    "Created date" : "Датум на креирање",
    "Sort by created date and summary." : "Подреди по датум на креирање и резиме.",
    "Last modified" : "Скоро изменети",
    "Sort by last-modified date and summary." : "Подреди по датум на последна промена и резиме.",
    "Completed date" : "Датум на завршување",
    "Sort by completed date." : "Подреди по датум на завршување.",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Подреди по приоритет и резиме.",
    "Alphabetically" : "Азбучно",
    "Sort by summary and priority." : "Подреди по резиме и приоритет.",
    "Manually" : "Рачно",
    "Sort by manual order." : "Подреди по рачен редослед.",
    "{complete} % completed" : "{complete} % завршено",
    "Add subtask" : "Додади подзадача",
    "Show subtasks" : "Прикажи подзадачи",
    "Hide subtasks" : "Сокриј подзадачи",
    "Delete task" : "Избриши задача",
    "[Yesterday]" : "[Вчера]",
    "[Today]" : "[Денес]",
    "[Tomorrow]" : "[Утре]",
    "[Completed yesterday]" : "[Завршени вчера]",
    "[Completed today]" : "[Завршени денес]",
    "[Completed tomorrow]" : "[Завршени утре]",
    "[Yesterday at] LT" : "[Вчера во] LT",
    "[Today at] LT" : "[Денес во] LT",
    "[Tomorrow at] LT" : "[Утре во] LT",
    "L [at] LT" : "L [во] LT",
    "[Completed yesterday at] LT" : "[Завршени вчера во] LT",
    "[Completed today at] LT" : "[Завршени денес во] LT",
    "[Completed tomorrow at] LT" : "[Завршени утре во] LT",
    "[Completed] L [at] LT" : "[Завршени] L [во] LT",
    "Add a subtask to \"{task}\"…" : "Додади подзадача во \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Бришење на задачата за {countdown} секунда","Бришење на задачата за {countdown} секунди"],
    "Task is completed" : "Задачата е завршена",
    "Cancel" : "Откажи",
    "Close" : "Затвори",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Завршена задача","%n Завршени задачи"],
    "Tomorrow" : "Утре",
    "Add List…" : "Додади листа...",
    "New List" : "Нова листа",
    "All day" : "Цели денови",
    "Details" : "Детали",
    "Select a classification" : "Избери класификација",
    "Select a status" : "Избери статус",
    "Select tags" : "Избери ознаки",
    "Notes" : "Белешки",
    "Reminders" : "Потсетници",
    "Repeat" : "Повтори",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделен, прикажи зафатено",
    "When shared hide this event" : "Кога е споделен, сокриј го настанот",
    "Needs action" : "Потребна е акција",
    "In process" : "Во тек",
    "Canceled" : "Откажано",
    "Loading task from server." : "Вчитување на задачите од серверот.",
    "Task not found!" : "Задачата не е пронајдена!",
    "[Starts today]" : "[Започнува денес]",
    "[Starts tomorrow]" : "[Започнува утре]",
    "[Starts on] LL" : "[Започнува на] LL",
    "[Started yesterday]" : "[Започна вчера]",
    "[Started on] LL" : "[Започна на] LL",
    "[Started today at] LT" : "[Започна денес во] LT",
    "[Starts today at] LT" : "[Започнува денес во] LT",
    "[Starts tomorrow at] LT" : "[Започнува утре во] LT",
    "[Starts on] LL [at] LT" : "[Започнува на] LL [во] LT",
    "[Started yesterday at] LT" : "[Започна вчера во] LT",
    "[Started on] LL [at] LT" : "[Започна на] LL [во] LT",
    "Set start date" : "Постави почетен датум",
    "[Due today]" : "[До денес]",
    "[Due tomorrow]" : "[До утре]",
    "[Due on] LL" : "[До] LL",
    "[Was due yesterday]" : "[Требаше вчера]",
    "[Was due on] LL" : "[Требање до] LL",
    "[Was due today at] LT" : "[Требаше до денес во] LT",
    "[Due today at] LT" : "[До денес во] LT",
    "[Due tomorrow at] LT" : "[До утре во] LT",
    "[Due on] LL [at] LT" : "[До] LL [во] LT",
    "[Was due yesterday at] LT" : "[Требаше вчера во] LT",
    "[Was due on] LL [at] LT" : "[Требање до] LL [во] LT",
    "Set due date" : "Постави краен рок",
    "Priority {priority}: low" : "Приоритет {priority}: низок",
    "Priority {priority}: medium" : "Приоритет {priority}: среден",
    "Priority {priority}: high" : "Приоритет {priority}: висок",
    "No priority assigned" : "Нема дадено приоритет",
    "{percent} % completed" : "{percent} % завршено",
    "Successfully created the task." : "Успешно креирана задача.",
    "Could not delete the task." : "Неможе да се избрише задачата.",
    "Synchronizing to the server." : "Синхронизација со серверот.",
    "Task successfully saved to server." : "Задачата е успешно зачувана на серверот.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Неможе да се ажурира задачата бидејќи постои некој промена во задачата на серверот. Кликете на освежи, локалните промени ќе се отфрлат.",
    "Could not update the task." : "Неможе да се ажурира задачата.",
    "Successfully updated the task." : "Успешно ажурирање на задачата.",
    "Task successfully moved to new calendar." : "Задачата е успешно преместена во нов календар.",
    "An error occurred" : "Настана грешка",
    "Message from {author} in {conversationName}" : "Порака од {author} во {conversationName}"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
